Index: include/gpu/GrTypesPriv.h |
diff --git a/include/gpu/GrTypesPriv.h b/include/gpu/GrTypesPriv.h |
index 9202742df9344b0b1245d9a2c56e26f23056b0ab..eaf1aa4050615805910e6719d9baa2f1343527ba 100644 |
--- a/include/gpu/GrTypesPriv.h |
+++ b/include/gpu/GrTypesPriv.h |
@@ -265,13 +265,13 @@ |
}; |
#ifdef SK_DEBUG |
-// Takes a pointer to a GrCaps, and will suppress prints if required |
-#define GrCapsDebugf(caps, ...) \ |
- if (!caps->suppressPrints()) { \ |
- SkDebugf(__VA_ARGS__); \ |
+// Takes a pointer to a GrContext, and will suppress prints if required |
+#define GrContextDebugf(context, ...) \ |
+ if (!context->suppressPrints()) { \ |
+ SkDebugf(__VA_ARGS__); \ |
} |
#else |
-#define GrCapsDebugf(caps, ...) |
+#define GrContextDebugf(context, ...) |
#endif |
#endif |